@@ -2,7 +2,7 @@ package App::CELL::Message;
 
 use strict;
 use warnings;
-use 5.10.0;
+use 5.010;
 
 use App::CELL::Config;
 use App::CELL::Log qw( $log );
@@ -17,11 +17,11 @@ App::CELL::Message - handle messages the user might see
 
 =head1 VERSION
 
-Version 0.132
+Version 0.137
 
 =cut
 
-our $VERSION = '0.132';
+our $VERSION = '0.137';
 
 
 
